OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Օրացույց",
    "Individual" : "Անհատ",
    "Group" : "Խումբ",
    "Room" : "Սենյակ",
    "Unknown" : "Անհայտ",
    "New event" : "Նոր դեպք",
    "group" : "խումբ",
    "Attendees" : "Մասնակիցներ",
    "Reminders" : "Հիշեցումներ",
    "Repeating" : "Կրկնվող",
    "Confirmed" : "Հաստատված",
    "Cancelled" : "Չեղարկված",
    "Global" : "Ընդհանուր",
    "Every day" : "Ամեն օր",
    "Every week" : "Ամեն շաբաթ",
    "Every month" : "Ամեն ամիս",
    "Every year" : "Ամեն տարի",
    "never" : "երբեք",
    "after" : "հետո",
    "5 minutes before" : "5 րոպե առաջ",
    "10 minutes before" : "10 րոպե առաջ",
    "15 minutes before" : "15 րոպե առաջ",
    "30 minutes before" : "30 րոպե առաջ",
    "1 hour before" : "1 ժամ առաջ",
    "2 hours before" : "2 ժամ առաջ",
    "sec" : "վրկ",
    "min" : "րոպե",
    "hours" : "ժամ",
    "days" : "օր",
    "week" : "շաբաթ",
    "start" : "սկիզբ",
    "end" : "վերջ",
    "Successfully imported" : "Հաջողությամբ ներմուծվեց",
    "Partially imported, 1 failure" : "Մասնակի ներմուծվեց, 1 ձախողում",
    "Partially imported, {n} failures" : "Մասնակի ներմուծվեց, {n} ձախողում",
    "{type} {time} before the event starts" : "{type} {time} մինչ միջոցառման սկիզբը",
    "{type} {time} before the event ends" : "{type} {time} մինչ միջոցառման ավարտը",
    "{type} {time} after the event starts" : "{type} {time} միջոցառման սկզբից հետո",
    "{type} {time} after the event ends" : "{type} {time} միջոցառման ավարտից հետո",
    "{type} at the event's start" : "{type} միջոցառման սկզբում",
    "{type} at the event's end" : "{type} միջոցառման ավարտին",
    "{calendar} shared by {owner}" : "{calendar} կիսված {owner}ի կողմից",
    "Title of the Event" : "Դեպքի վերնագիր",
    "All day Event" : "Շուրջօրյա դեպք",
    "Delete" : "Ջնջել",
    "Cancel" : "Չեղարկել",
    "More ..." : "Ավելին ...",
    "Create" : "Ստեղծել",
    "Update" : "Թարմացնել",
    "Close" : "Փակել",
    "Location" : "Տեղակայություն",
    "Description" : "Նկարագրություն",
    "Event status" : "Դեպքի կարգավիճակ",
    "Visibility when sharing" : "Տեսանելի կիսվելիս",
    "Export" : "Արտահանում",
    "Day" : "Օր",
    "Week" : "Շաբաթ",
    "Month" : "Ամիս",
    "Today" : "Այսօր",
    "Share Calendar" : "Կիսվել օրացույցով",
    "Shared" : "Կիսված",
    "More" : "Ավելի",
    "Edit" : "Խմբագրել",
    "Link" : "Հղում",
    "Download" : "Ներբեռնել",
    "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
    "can edit" : "կարող է խմբագրել",
    "New Calendar" : "Նոր օրացույց",
    "Name" : "Անուն",
    "New Subscription" : "Նոր բաժանորդագրություն",
    "Edit event" : "Խմբագրել դեպքը",
    "Delete Event" : "Ջնջել դեպքը",
    "Save Event" : "Պահել դեպքը",
    "Time" : "Ժամ",
    "Type" : "Տիպ",
    "Relative" : "Հարաբերական",
    "Absolute" : "Բացարձակ",
    "Repeat" : "Կրկնել",
    "times every" : "անգամ ամեն",
    "Add" : "Ավելացնել",
    "Please add your email address in the personal settings in order to add attendees." : "Մասնակիցներ ավելացնելու համար անձնական կարգավորումներում նշեք էլ. հասցե:",
    "Repeat every ..." : "Կրկնել ամեն ...",
    "times" : "անգամ",
    "Import canceled" : "Ներմուծումը չեղարկվեց",
    "Primary CalDAV address" : "Հիմնական CalDAV հասցե",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV հասցե"
},
"nplurals=2; plural=(n != 1);");
